billing

package
v0.0.0-...-a4e75fc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 28, 2026 License: Apache-2.0 Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCreateBillingDocController

func NewCreateBillingDocController(clock utilsclock.PassiveClock, azureLocation string, resourcesDBClient corecosmosstorage.ResourcesDBClient, billingDBClient billingcosmosstorage.BillingDBClient, clusterLister corelisters.ClusterLister, billingLister corelisters.BillingLister) controllerutils.ClusterSyncer

NewCreateBillingDocController creates a controller that ensures a billing document exists for clusters that have a ClusterUID and are in the Succeeded provisioning state.

func NewOrphanedBillingCleanupController

func NewOrphanedBillingCleanupController(clock utilsclock.PassiveClock, billingDBClient billingcosmosstorage.BillingDBClient, clusterLister corelisters.ClusterLister, billingLister corelisters.BillingLister) controllerutils.Controller

NewOrphanedBillingCleanupController creates a controller that marks billing documents as deleted when their corresponding cluster no longer exists in Cosmos DB.

Types

This section is empty.

Jump to