backups

package
v0.0.0-...-bdd5ccd Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 30, 2026 License: Apache-2.0 Imports: 24 Imported by: 0

Documentation

Overview

Copyright 2026 Microsoft Corporation

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

const BackupScheduleControllerName = "BackupSchedule"

Variables

This section is empty.

Functions

func NewBackupScheduleController

func NewBackupScheduleController(
	cosmosClient corecosmosstorage.ResourcesDBClient,
	kubeApplierDBClients kubeappliercosmosstorage.KubeApplierDBClients,
	informers coreinformers.BackendInformers,
	kubeApplierInformers *unionkubeapplierinformers.UnionKubeApplierInformers,
	hostedClusterNamespaceEnvIdentifier string,
	backupConfig *BackupConfig,
) controllerutils.Controller

func NewScheduledBackup

func NewScheduledBackup(resourceID, hostedClusterNamespace, controlPlaneNamespace string, backupScheduleConfig BackupScheduleConfig, paused bool) *velerov1api.Schedule

Types

type BackupCadenceProfile

type BackupCadenceProfile string
const (
	BackupCadenceProduction BackupCadenceProfile = "production"
	BackupCadenceTesting    BackupCadenceProfile = "testing"
)

type BackupConfig

type BackupConfig struct {
	BackupScheduleState  coreapi.BackupScheduleState
	BackupCadenceProfile BackupCadenceProfile
}

func (*BackupConfig) Schedules

func (c *BackupConfig) Schedules() []BackupScheduleConfig

type BackupScheduleConfig

type BackupScheduleConfig struct {
	Name     string
	Schedule string
	TTL      time.Duration
}

Jump to