validation

package
v0.0.0-...-7676576 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 29, 2026 License: Apache-2.0 Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewNodePoolValidationController

func NewNodePoolValidationController(
	validation validationutils.NodePoolValidation,
	resourcesDBClient corecosmosstorage.ResourcesDBClient,
	serviceProviderNodePoolLister corelisters.ServiceProviderNodePoolLister,
	informers coreinformers.BackendInformers,
	kubeApplierInformers *unionkubeapplierinformers.UnionKubeApplierInformers,
) controllerutils.Controller

NewNodePoolValidationController creates a new controller that executes the provided NodePool validation on each node pool.

Types

type MockNodePoolValidation

type MockNodePoolValidation struct {
	// contains filtered or unexported fields
}

MockNodePoolValidation is a NodePoolValidation implementation for controller tests.

func NewMockNodePoolValidation

func NewMockNodePoolValidation(name string) *MockNodePoolValidation

NewMockNodePoolValidation creates a mock validation with the given name and no result configured.

func (*MockNodePoolValidation) Name

func (m *MockNodePoolValidation) Name() string

func (*MockNodePoolValidation) WithEarliestRetryAfter

func (m *MockNodePoolValidation) WithEarliestRetryAfter(d *time.Duration) *MockNodePoolValidation

WithEarliestRetryAfter overrides the currently configured result's EarliestRetryAfter, e.g. to nil to exercise the "no retry backoff" path.

func (*MockNodePoolValidation) WithFailed

func (m *MockNodePoolValidation) WithFailed(reason, internalMessage, userMessage string) *MockNodePoolValidation

WithFailed configures the mock to return a failed validation result.

func (*MockNodePoolValidation) WithPassed

WithPassed configures the mock to return a passed validation result.

func (*MockNodePoolValidation) WithSkipped

func (m *MockNodePoolValidation) WithSkipped(reason, internalMessage, userMessage string) *MockNodePoolValidation

WithSkipped configures the mock to return a skipped validation result.

func (*MockNodePoolValidation) WithUnknownLogOnly

func (m *MockNodePoolValidation) WithUnknownLogOnly(reason, internalMessage, userMessage string) *MockNodePoolValidation

WithUnknownLogOnly configures the mock to return an unknown validation result with log-only reporting.

func (*MockNodePoolValidation) WithUnknownReportError

func (m *MockNodePoolValidation) WithUnknownReportError(reason, internalMessage, userMessage string) *MockNodePoolValidation

WithUnknownReportError configures the mock to return an unknown validation result that reports as an error.

Jump to