utils

package
v0.0.0-...-fecedb7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 10, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AnyToString

func AnyToString(value any) string

AnyToString maps some types to strings, as they are used in OS Env.

func GetOsVariable

func GetOsVariable() map[string]string

GetOsVariable looks up OS environment variables and returns them as a map. It also sets a special environment variable RUNS_IN_TEMPLATIZE to 1.

func MapToEnvVarArray

func MapToEnvVarArray(envVars map[string]string) []string

MapToEnvVarArray converts a map of environment variables to an array of strings.

Types

This section is empty.

Jump to