Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCreateBillingDocController ¶
func NewCreateBillingDocController(clock utilsclock.PassiveClock, azureLocation string, resourcesDBClient corecosmosstorage.ResourcesDBClient, billingDBClient billingcosmosstorage.BillingDBClient, clusterLister corelisters.ClusterLister, billingLister corelisters.BillingLister) controllerutils.ClusterSyncer
NewCreateBillingDocController creates a controller that ensures a billing document exists for clusters that have a ClusterUID and are in the Succeeded provisioning state.
func NewOrphanedBillingCleanupController ¶
func NewOrphanedBillingCleanupController(clock utilsclock.PassiveClock, billingDBClient billingcosmosstorage.BillingDBClient, clusterLister corelisters.ClusterLister, billingLister corelisters.BillingLister) controllerutils.Controller
NewOrphanedBillingCleanupController creates a controller that marks billing documents as deleted when their corresponding cluster no longer exists in Cosmos DB.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.