Documentation
¶
Index ¶
- Constants
- func NewClusterBaseDomainPrefixSyncController(resourcesDBClient corecosmosstorage.ResourcesDBClient, ...) controllerutils.Controller
- func NewClusterPropertiesSyncController(resourcesDBClient corecosmosstorage.ResourcesDBClient, ...) controllerutils.Controller
- func NewDesiredControlPlaneSizeController(resourcesDBClient corecosmosstorage.ResourcesDBClient, ...) controllerutils.Controller
- func NewServiceProviderClusterPropertiesSyncController(resourcesDBClient corecosmosstorage.ResourcesDBClient, ...) controllerutils.Controller
Constants ¶
const ServiceProviderClusterPropertiesSyncControllerName = "ServiceProviderClusterPropertiesSync"
Variables ¶
This section is empty.
Functions ¶
func NewClusterBaseDomainPrefixSyncController ¶
func NewClusterBaseDomainPrefixSyncController( resourcesDBClient corecosmosstorage.ResourcesDBClient, clusterServiceClient ocm.ClusterServiceClientSpec, informers coreinformers.BackendInformers, kubeApplierInformers *unionkubeapplierinformers.UnionKubeApplierInformers, ) controllerutils.Controller
NewClusterBaseDomainPrefixSyncController creates a controller that synchronizes CustomerProperties.DNS.BaseDomainPrefix from Cluster Service to Cosmos DB.
func NewClusterPropertiesSyncController ¶
func NewClusterPropertiesSyncController( resourcesDBClient corecosmosstorage.ResourcesDBClient, informers coreinformers.BackendInformers, kubeApplierInformers *unionkubeapplierinformers.UnionKubeApplierInformers, readDesireLister kubeapplierlisters.ReadDesireLister, ) controllerutils.Controller
NewClusterPropertiesSyncController creates a controller that synchronizes cluster properties from the HostedCluster ReadDesire mirror to Cosmos DB.
func NewDesiredControlPlaneSizeController ¶
func NewDesiredControlPlaneSizeController( resourcesDBClient corecosmosstorage.ResourcesDBClient, clusterServiceClient ocm.ClusterServiceClientSpec, informers coreinformers.BackendInformers, kubeApplierInformers *unionkubeapplierinformers.UnionKubeApplierInformers, ) controllerutils.Controller
NewDesiredControlPlaneSizeController creates a controller that reconciles ServiceProviderCluster.Status.DesiredHostedClusterControlPlaneSize against SPC Spec once the cluster update dispatch controller has applied the effective size override to cluster-service.
func NewServiceProviderClusterPropertiesSyncController ¶
func NewServiceProviderClusterPropertiesSyncController( resourcesDBClient corecosmosstorage.ResourcesDBClient, informers coreinformers.BackendInformers, kubeApplierInformers *unionkubeapplierinformers.UnionKubeApplierInformers, readDesireLister kubeapplierlisters.ReadDesireLister, ) controllerutils.Controller
NewServiceProviderClusterPropertiesSyncController creates a controller that synchronizes HostedClusterNamespace and ControlPlaneNamespace from the HostedCluster ReadDesire mirror to the ServiceProviderCluster in Cosmos DB.
Types ¶
This section is empty.